
<!--
FrozenIsBool False
-->

#Executer

##Doc
----


> 
> An Executer can exec commands with the six.exec_ function
> 

----

<small>
View the Executer notebook on [NbViewer](http://nbviewer.ipython.org/url/shareyoursystem.ouvaton.org/Executer.ipynb)
</small>

